@@ -57,6 +57,9 @@ class rdpThread(threading.Thread) :
 			gtk.gdk.threads_leave();
 			return False
 		#print "rdesktop-cli " + self.parameters + " " + self.host
+                self.ossoc = osso.Context("pyrdesktop", "1.6.0", False)
+                note = osso.SystemNote(osso_c)
+                note.system_note_infoprint("Connecting to '" + self.name + "'")
 		result = os.system("rdesktop-cli " + self.parameters + " " + self.host)
 		needEnter = False
 		#for thread in threading.enumerate():
@@ -216,6 +219,7 @@ class rdesktop:
 			load_prof = self.client.get_string("/apps/rdesktop/load_prof")
 			if load_prof != None :
 				self.load_profile("", "", "", "/apps/rdesktop/prof"+load_prof)
+                                self.current_profile = load_prof
 		else :
 			#No preferences?  Just make the /apps/rdesktop dir, and everything should work fine
 			self.client.add_dir("/apps/rdesktop", gconf.CLIENT_PRELOAD_NONE)
@@ -240,7 +244,8 @@ class rdesktop:
 			"show_about" : self.show_about,
 			"save_advanced" : self.ok_advanced,
 			"cancel_advanced" : self.cancel_advanced,
-                        "exp_preset_change" : self.exp_preset_change}
+                        "exp_preset_change" : self.exp_preset_change,
+                        "change_exp" : self.change_exp}
 		self.wTree.signal_autoconnect(dic)
 
 	def ErrPopUp(self,msg):
@@ -252,6 +257,11 @@ class rdesktop:
 		# error_dialog.connect("delete-event", delete_event, self)
 		self.error_dialog = error_dialog
 		error_dialog.run()
+                
+        def change_exp(self, widget) :
+                #Called when an experience box is toggled
+                #To avoid confusion, this should change the experience combo to "Custom"
+                self.cmb_exp_preset.set_active(4)
         
         def reset_exp_checks(self) :
                 self.chk_exp_desktop.set_active(False)
@@ -277,8 +287,10 @@ class rdesktop:
                 if self.cmb_exp_preset.get_active() >= 3 :
                         self.chk_exp_font.set_active(True)
                         self.chk_exp_desktop.set_active(True)
-                if self.cmb_exp_preset.get_active() == 4 :
-                        self.reset_exp_checks()
+                #if self.cmb_exp_preset.get_active() == 4 :
+                #        self.reset_exp_checks()
+                #At first, I thought selecting "Custom" should clear the checkboxes...
+                #  I changed my mind...
 
 	def ok_advanced(self, widget) :
 		self.dlg_advanced.hide()
@@ -442,6 +454,7 @@ class rdesktop:
                         tempexp = tempexp | 0x08
                 if self.chk_exp_bitmap.get_active() == False :
                         tempexp = tempexp | 0x40
+                to_run = to_run + " -x " + str(tempexp)
 
 		#Now run it! -- I'd like to be able to keep the GUI open, but I need to figure out threading, first...
 		#self.window.hide()
